@@ -1,8 +1,13 @@
+"""classicML的回调函数."""
+
+__version__ = 'backend.python.callbacks.0.2'
+
+
 class History(object):
     """保存训练的历史记录.
 
     Attributes:
-        name: str, default=None,
+        name: str, default='history',
             历史记录的名称.
         loss_name: str, default='loss'
             使用损失函数的名称.
@@ -12,12 +17,12 @@ class History(object):
         metric: list, 评估值组成的列表
 
     Notes:
-        - 使用该函数记录数据, 会导致运行速度的降低.
+        - 使用历史记录数据, 会导致运行速度的降低.
     """
-    def __init__(self, name=None, loss_name='loss', metric_name='metric'):
+    def __init__(self, name='history', loss_name='loss', metric_name='metric'):
         """
         Arguments:
-            name: str, default=None,
+            name: str, default='history',
                 历史记录的名称.
             loss_name: str, default='loss'
                 使用损失函数的名称.
