@@ -1,12 +1,16 @@
-"""classicML的初始化函数."""
+"""classicML的初始化器."""
 import numpy as np
 
+from classicML import _cml_precision
+
+__version__ = 'backend.python.initializers.0.6'
+
 
 class Initializer(object):
     """初始化器的基类.
 
     Attributes:
-        name: str, default=None,
+        name: str, default='initializer',
             初始化器的名称.
         seed: int, default=None,
             初始化器的随机种子.
@@ -14,10 +18,10 @@ class Initializer(object):
     Raises:
        NotImplementedError: __call__方法需要用户实现.
     """
-    def __init__(self, name=None, seed=None):
+    def __init__(self, name='initializer', seed=None):
         """
         Arguments:
-            name: str, default=None,
+            name: str, default='initializer',
                 初始化器的名称.
             seed: int, default=None,
                 初始化器的随机种子.
@@ -44,15 +48,16 @@ class RandomNormal(Initializer):
                 如果是逻辑回归就是样本的特征数;
                 如果是神经网络, 就是定义神经网络的网络结构.
         """
-        if isinstance(attributes_or_structure, int):
-            parameters = np.random.randn(attributes_or_structure + 1, 1)  # 初始化属性数+1(偏置项b)
+        if isinstance(attributes_or_structure, (int, _cml_precision.int)):
+            parameters = np.random.randn(attributes_or_structure + 1, 1).astype(_cml_precision.float)  # 初始化属性数+1(偏置项b)
         else:
             parameters = {}
             num_of_layers = len(attributes_or_structure)
 
             for layer in range(num_of_layers - 1):
-                w = np.random.randn(attributes_or_structure[layer + 1], attributes_or_structure[layer])
-                b = np.zeros((1, attributes_or_structure[layer + 1]))
+                w = np.random.randn(attributes_or_structure[layer + 1],
+                                    attributes_or_structure[layer]).astype(_cml_precision.float)
+                b = np.zeros([1, attributes_or_structure[layer + 1]], dtype=_cml_precision.float)
                 parameters['w' + str(layer + 1)] = w
                 parameters['b' + str(layer + 1)] = b
 
@@ -77,17 +82,17 @@ class HeNormal(Initializer):
                 如果是逻辑回归就是样本的特征数;
                 如果是神经网络, 就是定义神经网络的网络结构.
         """
-        if isinstance(attributes_or_structure, int):
+        if isinstance(attributes_or_structure, (int, _cml_precision.int)):
             parameters = (np.random.randn(attributes_or_structure + 1, 1)
-                          * np.sqrt(2 / attributes_or_structure))  # 初始化属性数+1(偏置项b)
+                          * np.sqrt(2 / attributes_or_structure)).astype(_cml_precision.float)  # 初始化属性数+1(偏置项b)
         else:
             parameters = {}
             num_of_layers = len(attributes_or_structure)
 
             for layer in range(num_of_layers - 1):
                 w = (np.random.randn(attributes_or_structure[layer + 1], attributes_or_structure[layer])
-                     * np.sqrt(2 / attributes_or_structure[layer]))
-                b = np.zeros((1, attributes_or_structure[layer + 1]))
+                     * np.sqrt(2 / attributes_or_structure[layer])).astype(_cml_precision.float)
+                b = np.zeros([1, attributes_or_structure[layer + 1]], dtype=_cml_precision.float)
                 parameters['w' + str(layer + 1)] = w
                 parameters['b' + str(layer + 1)] = b
 
@@ -99,8 +104,8 @@ class XavierNormal(Initializer):
         也叫做Glorot正态分布随机初始化器.
 
     References:
-        - [Glorot et al., 2010](http://proceedings.mlr.press/v9/glorot10a.html)
-          ([pdf](http://jmlr.org/proceedings/papers/v9/glorot10a/glorot10a.pdf))
+        - [Glorot et al., 2010](https://proceedings.mlr.press/v9/glorot10a.html)
+          ([pdf](https://jmlr.org/proceedings/papers/v9/glorot10a/glorot10a.pdf))
     """
     def __init__(self, name='xavier_normal', seed=None):
         super(XavierNormal, self).__init__(name=name, seed=seed)
@@ -114,19 +119,19 @@ class XavierNormal(Initializer):
                 如果是逻辑回归就是样本的特征数;
                 如果是神经网络, 就是定义神经网络的网络结构.
         """
-        if isinstance(attributes_or_structure, int):
+        if isinstance(attributes_or_structure, (int, _cml_precision.int)):
             # 逻辑回归没有多层结构
             # 令 2 / (N_in + N_out) = 2 / N_in * 2, 即 N_in
             parameters = (np.random.randn(attributes_or_structure + 1, 1)
-                          * np.sqrt(attributes_or_structure))
+                          * np.sqrt(attributes_or_structure)).astype(_cml_precision.float)
         else:
             parameters = {}
             num_of_layers = len(attributes_or_structure)
 
             for layer in range(num_of_layers - 1):
                 w = (np.random.randn(attributes_or_structure[layer + 1], attributes_or_structure[layer])
-                     * np.sqrt(2 / (attributes_or_structure[layer] + attributes_or_structure[layer + 1])))
-                b = np.zeros((1, attributes_or_structure[layer + 1]))
+                     * np.sqrt(2 / (attributes_or_structure[layer] + attributes_or_structure[layer + 1]))).astype(_cml_precision.float)
+                b = np.zeros([1, attributes_or_structure[layer + 1]], dtype=_cml_precision.float)
                 parameters['w' + str(layer + 1)] = w
                 parameters['b' + str(layer + 1)] = b
 
@@ -157,9 +162,9 @@ class RBFNormal(Initializer):
               但是实际工程发现, 有负值的时候可能会导致求高斯函数的时候增加损失不收敛,
               因此, 全部初始化为正数.
         """
-        parameters = {'w': np.zeros([1, hidden_units]),
-                      'b': np.zeros([1, 1]),
-                      'c': np.random.rand(hidden_units, 2),  # 隐含层神经元的中心
-                      'beta': np.random.randn(1, hidden_units)}  # 高斯径向基函数的系数
+        parameters = {'w': np.zeros([1, hidden_units], dtype=_cml_precision.float),
+                      'b': np.zeros([1, 1], dtype=_cml_precision.float),
+                      'c': np.random.rand(hidden_units, 2).astype(_cml_precision.float),  # 隐含层神经元的中心
+                      'beta': np.random.randn(1, hidden_units).astype(_cml_precision.float)}  # 高斯径向基函数的系数
 
-        return parameters
\ No newline at end of file
+        return parameters
